import {Component, OnDestroy} from '@angular/core';
import {AvatarModule} from 'primeng/avatar';
import {Button, ButtonDirective} from 'primeng/button';
import {AuthorService} from '../services/author.service';
import {Author} from '../model/author';
import {JsonPipe} from '@angular/common';
import {Subscription} from 'rxjs';
import {PostService} from '../services/post.service';
import {Header, MessageService} from 'primeng/api';
import {HeaderComponent} from '../header/header.component';
import {ToastModule} from 'primeng/toast';
import {CookieService} from 'ngx-cookie-service';

@Component({
  selector: 'app-home',
  standalone: true,
  imports: [
    AvatarModule,
    Button,
    HeaderComponent,
    ToastModule,
    JsonPipe
  ],
  providers: [
    MessageService,
  ],
  templateUrl: './home.component.html',
  styleUrl: './home.component.css'
})
export class HomeComponent implements OnDestroy {
  actualAuthor: Author | undefined;
  authors: Author[] = []
  subs: Subscription[] = []

  constructor(
    private authorService: AuthorService,
    private postService: PostService,
    private messageService: MessageService,
    private cookieService: CookieService) {

    if (this.cookieService.get('author')) {
      this.actualAuthor = JSON.parse(this.cookieService.get('author'));
      if (this.cookieService.get("just-authenticated")) {
        this.successMessage('Connecté avec succès', `Heureux de vous revoir ${this.actualAuthor?.name}`);
      }
    }
    this.subs.push(authorService.list()
      .subscribe({
        next: (authors: Author[]) => this.authors = authors,
        error: (err) => console.error(err.message),
      }));
  }

  successMessage(summary: string, detail: string): void {
    this.messageService.add({
      severity: 'success',
      summary: summary,
      detail: detail,
      life: 1500,
      closable: false
    });
  }

  ngOnDestroy(): void {
    this.subs.forEach(sub => sub.unsubscribe());
  }

}
